"use strict";

require("core-js/modules/es.symbol");

require("core-js/modules/es.array.filter");

require("core-js/modules/es.array.flat-map");

require("core-js/modules/es.array.for-each");

require("core-js/modules/es.array.map");

require("core-js/modules/es.array.unscopables.flat-map");

require("core-js/modules/es.object.define-properties");

require("core-js/modules/es.object.define-property");

require("core-js/modules/es.object.get-own-property-descriptor");

require("core-js/modules/es.object.get-own-property-descriptors");

require("core-js/modules/es.object.keys");

require("core-js/modules/es.string.sup");

require("core-js/modules/web.dom-collections.for-each");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = void 0;

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

var ChordTexts = function ChordTexts() {
  var scale = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : 1;
  var defaultSizeChord = 30 * scale;
  var defaultSizeBass = 25 * scale;
  var defaultSizeSup = 25 * scale;
  var strokeWidth = 3 * scale;

  var getAttr = function getAttr(fontSize) {
    return {
      fill: "#000",
      fontSize: fontSize,
      fontFamily: "jazz-font,Verdana,Courier",
      textAnchor: "start"
    };
  }; // repeat chord sign: %


  var getRepeatSign = function getRepeatSign(x, y) {
    var MARGIN_REPEAT_SIGN = 10;
    var repeatSignX = x + MARGIN_REPEAT_SIGN;
    var repeatSignY = y + MARGIN_REPEAT_SIGN * scale;
    var repeatSignSize = 20 * scale;
    var circle = {
      r: 3 * scale,
      stroke: "black",
      fill: "black"
    };
    var circles = [_objectSpread(_objectSpread({}, circle), {
      cx: repeatSignX,
      cy: repeatSignY - repeatSignSize
    }), _objectSpread(_objectSpread({}, circle), {
      cx: repeatSignX + repeatSignSize,
      cy: repeatSignY
    })];
    var lines = [];
    lines.push({
      d: "M " + repeatSignX + " " + repeatSignY + " l " + repeatSignSize + " " + -1 * repeatSignSize,
      strokeWidth: strokeWidth,
      stroke: "black"
    });
    return {
      lines: lines,
      texts: [],
      circles: circles
    };
  };

  var getChordSvgElems = function getChordSvgElems(chord, x, y) {
    if (chord.same) return getRepeatSign(x, y);
    y += 5; //due to font, we have to put them 5 points higher

    var lines = [];
    var chordText = chord.pitch + chord.chordType;
    var texts = [_objectSpread({
      x: x,
      y: y,
      text: chordText
    }, getAttr(defaultSizeChord))];

    if (chord.sup) {
      texts.push(_objectSpread({
        x: x + scale * (chordText.length * 10 + 5),
        y: y - scale * (defaultSizeChord / 3),
        text: chord.sup
      }, getAttr(defaultSizeSup)));
    }

    if (chord.bass) {
      var bassX = x + scale * (chordText.length * 10);
      var bassY = y + scale * 25;
      texts.push(_objectSpread({
        x: bassX,
        y: bassY,
        text: chord.bass
      }, getAttr(defaultSizeBass)));
      lines.push({
        d: "M" + (bassX - scale * 10) + " " + (y + scale * 10) + " l " + scale * 24 + " " + scale * -15,
        strokeWidth: strokeWidth,
        stroke: "black"
      });
    }

    var returnObj = {
      texts: texts
    };
    if (lines.length) returnObj.lines = lines;
    return returnObj;
  };

  var getSvgElems = function getSvgElems(bars, barView) {
    var timeSignature = bars[0].timeSignature || "44";
    var barChordsText = bars.map(function (bar) {
      var startXList = barView.getStartXList(timeSignature, bar.chords.map(function (chord) {
        return chord.duration;
      }));
      var barChords = bar.chords.map(function (chord, i) {
        chord.startX = startXList[i];
        return chord;
      });
      var chordTexts = barChords.map(function (chord) {
        var x = bar.dimensions.x + chord.startX;
        var y = bar.dimensions.y + barView.bar.padding.top;
        return getChordSvgElems(chord, x, y);
      });
      var lines = chordTexts.filter(function (chord) {
        return !!chord.lines;
      }).flatMap(function (chord) {
        return chord.lines;
      });
      var circles = chordTexts.filter(function (chord) {
        return !!chord.circles;
      }).flatMap(function (chord) {
        return chord.circles;
      });
      chordTexts = chordTexts.flatMap(function (chord) {
        return chord.texts;
      });
      return {
        startXList: startXList,
        chordTexts: chordTexts,
        lines: lines,
        circles: circles
      };
    });
    var barCircles = barChordsText.filter(function (bar) {
      return !!bar.circles;
    }).flatMap(function (bar) {
      return bar.circles;
    });
    var barLines = barChordsText.filter(function (bar) {
      return !!bar.lines;
    }).flatMap(function (bar) {
      return bar.lines;
    });
    var startXList = barChordsText.map(function (bar) {
      return bar.startXList;
    });
    barChordsText = barChordsText.flatMap(function (bar) {
      return bar.chordTexts;
    });
    var returnObj = {
      texts: barChordsText,
      startX: startXList
    };
    if (barLines) returnObj.paths = barLines;
    if (barCircles) returnObj.circles = barCircles;
    return returnObj;
  };

  return {
    getChordSvgElems: getChordSvgElems,
    getSvgElems: getSvgElems
  };
};

var _default = ChordTexts;
exports["default"] = _default;